@@ -3,7 +3,7 @@ use warnings;
 
 package HTTP::Async;
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use Carp;
 use Data::Dumper;
@@ -793,7 +793,8 @@ handle 304 responses.
 
 Naveed Massjouni for adding the https handling code.
 
-Alex Balhatchet for adding the https + proxy handling code.
+Alex Balhatchet for adding the https + proxy handling code, and for making the
+tests run ok in parallel.
 
 =head1 BUGS AND REPO
 
